netapp_ontap.models.anti_ransomware_suspect_file API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.anti_ransomware_suspect_file`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AntiRansomwareSuspectFileSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AntiRansomwareSuspectFile object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `format: str GET POST PATCH`

    File format of the suspected file.

    Example: pdf

  `name: str GET POST PATCH`

    Name of the suspected file.

    Example: test_file

  `path: str GET POST PATCH`

    Path of the suspected file.

    Example: d1/d2/d3

  `reason: str GET POST PATCH`

    Reason behind this file being suspected

    Example: High Entropy

  `suspect_time: ImpreciseDateTime GET`

    Time when the file was detected as a potential suspect in date-time format.

    Example: 2021-05-12T15:00:16.000+0000